package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WyBeerStyleMapper;
import com.ruoyi.system.domain.WyBeerStyle;
import com.ruoyi.system.service.IWyBeerStyleService;

/**
 * 酒款风格Service业务层处理
 * 
 * @author kxl
 * @date 2025-03-08
 */
@Service
public class WyBeerStyleServiceImpl implements IWyBeerStyleService 
{
    @Autowired
    private WyBeerStyleMapper wyBeerStyleMapper;

    /**
     * 查询酒款风格
     * 
     * @param id 酒款风格主键
     * @return 酒款风格
     */
    @Override
    public WyBeerStyle selectWyBeerStyleById(Long id)
    {
        return wyBeerStyleMapper.selectWyBeerStyleById(id);
    }

    /**
     * 查询酒款风格列表
     * 
     * @param wyBeerStyle 酒款风格
     * @return 酒款风格
     */
    @Override
    public List<WyBeerStyle> selectWyBeerStyleList(WyBeerStyle wyBeerStyle)
    {
        return wyBeerStyleMapper.selectWyBeerStyleList(wyBeerStyle);
    }

    @Override
    public List<WyBeerStyle> selectWyBeerStyleTree()
    {
        final WyBeerStyle wyBeerStyle = new WyBeerStyle();
        wyBeerStyle.setParentId(0L);
        final List<WyBeerStyle> wyBeerStyles = wyBeerStyleMapper.selectWyBeerStyleList(wyBeerStyle);
        wyBeerStyles.forEach(item -> {
            final WyBeerStyle sub = new WyBeerStyle();
            sub.setParentId(item.getId());
            final List<WyBeerStyle> children = wyBeerStyleMapper.selectWyBeerStyleList(sub);
            item.setChildren(children);
        });
        return wyBeerStyles;
    }

    /**
     * 新增酒款风格
     * 
     * @param wyBeerStyle 酒款风格
     * @return 结果
     */
    @Override
    public int insertWyBeerStyle(WyBeerStyle wyBeerStyle)
    {
        return wyBeerStyleMapper.insertWyBeerStyle(wyBeerStyle);
    }

    /**
     * 修改酒款风格
     * 
     * @param wyBeerStyle 酒款风格
     * @return 结果
     */
    @Override
    public int updateWyBeerStyle(WyBeerStyle wyBeerStyle)
    {
        return wyBeerStyleMapper.updateWyBeerStyle(wyBeerStyle);
    }

    /**
     * 批量删除酒款风格
     * 
     * @param ids 需要删除的酒款风格主键
     * @return 结果
     */
    @Override
    public int deleteWyBeerStyleByIds(Long[] ids)
    {
        return wyBeerStyleMapper.deleteWyBeerStyleByIds(ids);
    }

    /**
     * 删除酒款风格信息
     * 
     * @param id 酒款风格主键
     * @return 结果
     */
    @Override
    public int deleteWyBeerStyleById(Long id)
    {
        return wyBeerStyleMapper.deleteWyBeerStyleById(id);
    }
}
