package com.ruoyi.brewery.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.core.domain.entity.WyBreweryUserRole;
import com.ruoyi.brewery.service.IWyBreweryUserRoleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 品牌方用户和角色关联Controller
 * 
 * @author ruoyi
 * @date 2024-12-22
 */
@Api(tags = "品牌方用户和角色关联")
@RestController
@RequestMapping("/brewery/userRole")
public class BreweryUserRoleController extends BaseController
{
    @Autowired
    private IWyBreweryUserRoleService wyBreweryUserRoleService;

    /**
     * 查询品牌方用户和角色关联列表
     */
    @ApiOperation("查询品牌方用户和角色关联列表")
    @PreAuthorize("@bss.hasPermi('brewery:userRole:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyBreweryUserRole wyBreweryUserRole)
    {
        startPage();
        List<WyBreweryUserRole> list = wyBreweryUserRoleService.selectWyBreweryUserRoleList(wyBreweryUserRole);
        return getDataTable(list);
    }

    /**
     * 导出品牌方用户和角色关联列表
     */
    @ApiOperation("导出品牌方用户和角色关联列表")
    @PreAuthorize("@bss.hasPermi('brewery:userRole:export')")
    @Log(title = "品牌方用户和角色关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyBreweryUserRole wyBreweryUserRole)
    {
        List<WyBreweryUserRole> list = wyBreweryUserRoleService.selectWyBreweryUserRoleList(wyBreweryUserRole);
        ExcelUtil<WyBreweryUserRole> util = new ExcelUtil<WyBreweryUserRole>(WyBreweryUserRole.class);
        util.exportExcel(response, list, "品牌方用户和角色关联数据");
    }

    /**
     * 获取品牌方用户和角色关联详细信息
     */
    @ApiOperation("获取品牌方用户和角色关联详细信息")
    @PreAuthorize("@bss.hasPermi('brewery:userRole:query')")
    @GetMapping(value = "/{userId}")
    public AjaxResult getInfo(@PathVariable("userId") Long userId)
    {
        return success(wyBreweryUserRoleService.selectWyBreweryUserRoleByUserId(userId));
    }

    /**
     * 新增品牌方用户和角色关联
     */
    @ApiOperation("新增品牌方用户和角色关联")
    @PreAuthorize("@bss.hasPermi('brewery:userRole:add')")
    @Log(title = "品牌方用户和角色关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WyBreweryUserRole wyBreweryUserRole)
    {
        return toAjax(wyBreweryUserRoleService.insertWyBreweryUserRole(wyBreweryUserRole));
    }

    /**
     * 修改品牌方用户和角色关联
     */
    @ApiOperation("修改品牌方用户和角色关联")
    @PreAuthorize("@bss.hasPermi('brewery:userRole:edit')")
    @Log(title = "品牌方用户和角色关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WyBreweryUserRole wyBreweryUserRole)
    {
        return toAjax(wyBreweryUserRoleService.updateWyBreweryUserRole(wyBreweryUserRole));
    }

    /**
     * 删除品牌方用户和角色关联
     */
    @ApiOperation("删除品牌方用户和角色关联")
    @PreAuthorize("@bss.hasPermi('brewery:userRole:remove')")
    @Log(title = "品牌方用户和角色关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{userIds}")
    public AjaxResult remove(@PathVariable Long[] userIds)
    {
        return toAjax(wyBreweryUserRoleService.deleteWyBreweryUserRoleByUserIds(userIds));
    }
}
