package com.ruoyi.brewery.controller;

import com.ruoyi.brewery.domain.WyBeer;
import com.ruoyi.brewery.domain.WyBeerQrcode;
import com.ruoyi.brewery.domain.WyBeerReview;
import com.ruoyi.brewery.service.IWyBeerReviewService;
import com.ruoyi.brewery.service.IWyBeerService;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.service.IWyBeerStyleService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;

/**
 * 酒评Controller
 *
 * @author ruoyi
 * @date 2024-12-21
 */
@Api(tags = "酒评")
@RestController
@RequestMapping("/brewery/review")
public class BreweryWyBeerReviewController extends BaseController
{
    @Autowired
    private IWyBeerReviewService wyBeerReviewService;
    @Resource
    private IWyBeerService beerService;
    /**
     * 查询酒评列表
     */
    @ApiOperation("查询酒评列表")
    @PreAuthorize("@bss.hasPermi('brewery:review:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyBeerReview wyBeerReview)
    {
        wyBeerReview.setBreweryId(SecurityUtils.getBreweryLoginUser().getBreweryId());
        startPage();
//        List<WyBeerReview> list = wyBeerReviewService.selectWyBeerReviewListWithBrewery(wyBeerReview);
        List<WyBeerReview> list = wyBeerReviewService.selectWyBeerReviewList(wyBeerReview);
        return getDataTable(list);
    }

    /**
     * 导出酒评列表
     */
    @ApiOperation("导出酒评列表")
    @PreAuthorize("@bss.hasPermi('brewery:review:export')")
    @Log(title = "酒评", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyBeerReview wyBeerReview)
    {
        List<WyBeerReview> list = wyBeerReviewService.selectWyBeerReviewList(wyBeerReview);
        ExcelUtil<WyBeerReview> util = new ExcelUtil<WyBeerReview>(WyBeerReview.class);
        util.exportExcel(response, list, "酒评数据");
    }

    /**
     * 获取酒评详细信息
     */
    @ApiOperation("获取酒评详细信息")
    @PreAuthorize("@bss.hasPermi('brewery:review:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        validate(id);
        return success(wyBeerReviewService.selectWyBeerReviewById(id));
    }

    /**
     * 酒评top10的酒款
     */
    @ApiOperation("酒评top10的酒款")
    @PreAuthorize("@bss.hasPermi('brewery:review:top10BeersList')")
    @GetMapping("/top10BeersList")
    public AjaxResult top10BeersList()
    {
        final WyBeer wyBeer = new WyBeer();
        wyBeer.setBreweryId(SecurityUtils.getBreweryLoginUser().getBreweryId());
        final List<WyBeer> wyBeers = beerService.top10BeersList(wyBeer);
        return AjaxResult.success(wyBeers);
    }

    /**
     * 置顶酒评
     */
    @ApiOperation("置顶酒评")
    @PreAuthorize("@bss.hasPermi('brewery:review:setTop')")
    @Log(title = "置顶酒评", businessType = BusinessType.UPDATE)
    @PostMapping("/setTop")
    public AjaxResult setTop(@RequestParam("id") Long id)
    {
        validate(id);
        wyBeerReviewService.setWyBeerReviewTop(id);
        return AjaxResult.success("置顶成功");
    }

    /**
     * 取消置顶酒评
     */
    @ApiOperation("取消置顶酒评")
    @PreAuthorize("@bss.hasPermi('brewery:review:cancelTop')")
    @Log(title = "取消置顶酒评", businessType = BusinessType.UPDATE)
    @PostMapping("/cancelTop")
    public AjaxResult cancelTop(@RequestParam("id") Long id)
    {
        validate(id);
        wyBeerReviewService.cancelWyBeerReviewTop(id);
        return AjaxResult.success("取消置顶成功");
    }

    /**
     * 新增酒评
     */
//    @ApiOperation("新增酒评")
//    @PreAuthorize("@bss.hasPermi('brewery:review:add')")
//    @Log(title = "酒评", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody WyBeerReview wyBeerReview)
//    {
//        return toAjax(wyBeerReviewService.insertWyBeerReview(wyBeerReview));
//    }

    /**
     * 修改酒评
     */
//    @ApiOperation("修改酒评")
//    @PreAuthorize("@bss.hasPermi('brewery:review:edit')")
//    @Log(title = "酒评", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody WyBeerReview wyBeerReview)
//    {
//        return toAjax(wyBeerReviewService.updateWyBeerReview(wyBeerReview));
//    }

    /**
     * 删除酒评
     */
//    @ApiOperation("删除酒评")
//    @PreAuthorize("@bss.hasPermi('brewery:review:remove')")
//    @Log(title = "酒评", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{ids}")
//    public AjaxResult remove(@PathVariable Long[] ids)
//    {
//        return toAjax(wyBeerReviewService.deleteWyBeerReviewByIds(ids));
//    }

    private void validate(Long id) {
        final WyBeerReview wyBeerReview = wyBeerReviewService.selectWyBeerReviewById(id);
        if (wyBeerReview == null) {
            throw new IllegalArgumentException("酒评不存在");
        }
        if (!SecurityUtils.getBreweryLoginUser().getBreweryId().equals(wyBeerReview.getBreweryId())) {
            throw new IllegalArgumentException("只能操作自己的品牌方的酒评");
        }
    }
}
