package com.ruoyi.web.controller.bar;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.bar.domain.WyBarRoleMenu;
import com.ruoyi.bar.service.IWyBarRoleMenuService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 品牌方角色和菜单关联Controller
 * 
 * @author ruoyi
 * @date 2025-01-04
 */
@RestController
@RequestMapping("/system/bar/barRoleMmenu")
public class WyBarRoleMenuController extends BaseController
{
    @Autowired
    private IWyBarRoleMenuService wyBarRoleMenuService;

    /**
     * 查询品牌方角色和菜单关联列表
     */
    @PreAuthorize("@ss.hasPermi('bar:barRoleMmenu:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyBarRoleMenu wyBarRoleMenu)
    {
        startPage();
        List<WyBarRoleMenu> list = wyBarRoleMenuService.selectWyBarRoleMenuList(wyBarRoleMenu);
        return getDataTable(list);
    }

    /**
     * 导出品牌方角色和菜单关联列表
     */
    @PreAuthorize("@ss.hasPermi('bar:barRoleMmenu:export')")
    @Log(title = "品牌方角色和菜单关联", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyBarRoleMenu wyBarRoleMenu)
    {
        List<WyBarRoleMenu> list = wyBarRoleMenuService.selectWyBarRoleMenuList(wyBarRoleMenu);
        ExcelUtil<WyBarRoleMenu> util = new ExcelUtil<WyBarRoleMenu>(WyBarRoleMenu.class);
        util.exportExcel(response, list, "品牌方角色和菜单关联数据");
    }

    /**
     * 获取品牌方角色和菜单关联详细信息
     */
    @PreAuthorize("@ss.hasPermi('bar:barRoleMmenu:query')")
    @GetMapping(value = "/{roleId}")
    public AjaxResult getInfo(@PathVariable("roleId") Long roleId)
    {
        return success(wyBarRoleMenuService.selectWyBarRoleMenuByRoleId(roleId));
    }

    /**
     * 新增品牌方角色和菜单关联
     */
    @PreAuthorize("@ss.hasPermi('bar:barRoleMmenu:add')")
    @Log(title = "品牌方角色和菜单关联", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WyBarRoleMenu wyBarRoleMenu)
    {
        return toAjax(wyBarRoleMenuService.insertWyBarRoleMenu(wyBarRoleMenu));
    }

    /**
     * 修改品牌方角色和菜单关联
     */
    @PreAuthorize("@ss.hasPermi('bar:barRoleMmenu:edit')")
    @Log(title = "品牌方角色和菜单关联", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WyBarRoleMenu wyBarRoleMenu)
    {
        return toAjax(wyBarRoleMenuService.updateWyBarRoleMenu(wyBarRoleMenu));
    }

    /**
     * 删除品牌方角色和菜单关联
     */
    @PreAuthorize("@ss.hasPermi('bar:barRoleMmenu:remove')")
    @Log(title = "品牌方角色和菜单关联", businessType = BusinessType.DELETE)
	@DeleteMapping("/{roleIds}")
    public AjaxResult remove(@PathVariable Long[] roleIds)
    {
        return toAjax(wyBarRoleMenuService.deleteWyBarRoleMenuByRoleIds(roleIds));
    }
}
