package com.ruoyi.web.controller.brewery;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.brewery.domain.WyBeerReviewLike;
import com.ruoyi.brewery.service.IWyBeerReviewLikeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 酒评点赞Controller
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
@Api(tags = "酒评点赞")
@RestController
@RequestMapping("/system/brewery/like")
public class WyBeerReviewLikeController extends BaseController
{
    @Autowired
    private IWyBeerReviewLikeService wyBeerReviewLikeService;

    /**
     * 查询酒评点赞列表
     */
    @ApiOperation("查询酒评点赞列表")
    @PreAuthorize("@ss.hasPermi('brewery:like:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyBeerReviewLike wyBeerReviewLike)
    {
        startPage();
        List<WyBeerReviewLike> list = wyBeerReviewLikeService.selectWyBeerReviewLikeList(wyBeerReviewLike);
        return getDataTable(list);
    }

    /**
     * 导出酒评点赞列表
     */
    @ApiOperation("导出酒评点赞列表")
    @PreAuthorize("@ss.hasPermi('brewery:like:export')")
    @Log(title = "酒评点赞", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyBeerReviewLike wyBeerReviewLike)
    {
        List<WyBeerReviewLike> list = wyBeerReviewLikeService.selectWyBeerReviewLikeList(wyBeerReviewLike);
        ExcelUtil<WyBeerReviewLike> util = new ExcelUtil<WyBeerReviewLike>(WyBeerReviewLike.class);
        util.exportExcel(response, list, "酒评点赞数据");
    }

    /**
     * 获取酒评点赞详细信息
     */
    @ApiOperation("获取酒评点赞详细信息")
    @PreAuthorize("@ss.hasPermi('brewery:like:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wyBeerReviewLikeService.selectWyBeerReviewLikeById(id));
    }

    /**
     * 新增酒评点赞
     */
    @ApiOperation("新增酒评点赞")
    @PreAuthorize("@ss.hasPermi('brewery:like:add')")
    @Log(title = "酒评点赞", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WyBeerReviewLike wyBeerReviewLike)
    {
        return toAjax(wyBeerReviewLikeService.insertWyBeerReviewLike(wyBeerReviewLike));
    }

    /**
     * 修改酒评点赞
     */
    @ApiOperation("修改酒评点赞")
    @PreAuthorize("@ss.hasPermi('brewery:like:edit')")
    @Log(title = "酒评点赞", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WyBeerReviewLike wyBeerReviewLike)
    {
        return toAjax(wyBeerReviewLikeService.updateWyBeerReviewLike(wyBeerReviewLike));
    }

    /**
     * 删除酒评点赞
     */
    @ApiOperation("删除酒评点赞")
    @PreAuthorize("@ss.hasPermi('brewery:like:remove')")
    @Log(title = "酒评点赞", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wyBeerReviewLikeService.deleteWyBeerReviewLikeByIds(ids));
    }
}
