package com.ruoyi.web.controller.brewery;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.brewery.domain.WyGoods;
import com.ruoyi.brewery.service.IWyGoodsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 兑换商品Controller
 * 
 * @author ruoyi
 * @date 2024-12-21
 */
@Api(tags = "兑换商品")
@RestController
@RequestMapping("/system/brewery/goods")
public class WyGoodsController extends BaseController
{
    @Autowired
    private IWyGoodsService wyGoodsService;

    /**
     * 查询兑换商品列表
     */
    @ApiOperation("查询兑换商品列表")
    @PreAuthorize("@ss.hasPermi('brewery:goods:list')")
    @GetMapping("/list")
    public TableDataInfo list(WyGoods wyGoods)
    {
        startPage();
        List<WyGoods> list = wyGoodsService.selectWyGoodsList(wyGoods);
        return getDataTable(list);
    }

    /**
     * 导出兑换商品列表
     */
    @ApiOperation("导出兑换商品列表")
    @PreAuthorize("@ss.hasPermi('brewery:goods:export')")
    @Log(title = "兑换商品", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WyGoods wyGoods)
    {
        List<WyGoods> list = wyGoodsService.selectWyGoodsList(wyGoods);
        ExcelUtil<WyGoods> util = new ExcelUtil<WyGoods>(WyGoods.class);
        util.exportExcel(response, list, "兑换商品数据");
    }

    /**
     * 获取兑换商品详细信息
     */
    @ApiOperation("获取兑换商品详细信息")
    @PreAuthorize("@ss.hasPermi('brewery:goods:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wyGoodsService.selectWyGoodsById(id));
    }

    /**
     * 新增兑换商品
     */
    @ApiOperation("新增兑换商品")
    @PreAuthorize("@ss.hasPermi('brewery:goods:add')")
    @Log(title = "兑换商品", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WyGoods wyGoods)
    {
        return toAjax(wyGoodsService.insertWyGoods(wyGoods));
    }

    /**
     * 修改兑换商品
     */
    @ApiOperation("修改兑换商品")
    @PreAuthorize("@ss.hasPermi('brewery:goods:edit')")
    @Log(title = "兑换商品", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WyGoods wyGoods)
    {
        return toAjax(wyGoodsService.updateWyGoods(wyGoods));
    }

    /**
     * 删除兑换商品
     */
    @ApiOperation("删除兑换商品")
    @PreAuthorize("@ss.hasPermi('brewery:goods:remove')")
    @Log(title = "兑换商品", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wyGoodsService.deleteWyGoodsByIds(ids));
    }
}
